==> vtigercrm-5.0.4p0.tgz: vtigercrm/modules/uploads/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/vtigercrm/modules/uploads/language/en_us.lang.php,v 1.1 2005/01/20 05:29:32 saraj Exp $
 * Description:  Defines the English language pack
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = Array(

//Added fields for uploads (attach files)
'LBL_ATTACH_FILE'=>'Attach File',
'LBL_ATTACH'=>'Attach',
'LBL_CANCEL'=>'Cancel',
'LBL_STEP_SELECT_FILE'=>'Step 1 : Select File',
'LBL_BROWSE_FILES'=>'Click the browse button and select the file to be attached',
'LBL_DESCRIPTION'=>'Step 2 : Write some description',
'LBL_OPTIONAL'=>'(optional)',
);

?>

==> vtigercrm-5.4.0.tgz: vtigercrm/modules/uploads/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/vtigercrm/modules/uploads/language/en_us.lang.php,v 1.1 2005/01/20 05:29:32 saraj Exp $
 * Description:  Defines the English language pack for uploads.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = Array(

//Added fields for uploads (attach files)
'LBL_ATTACH_FILE'=>'Attach File',
'LBL_ATTACH'=>'Attach',
'LBL_CANCEL'=>'Cancel',
'LBL_STEP_SELECT_FILE'=>'Step 1 : Select File',
'LBL_BROWSE_FILES'=>'Click the browse button and select the file to be attached',
'LBL_DESCRIPTION'=>'Step 2 : Write some description',
'LBL_OPTIONAL'=>'(optional)',
);

?>
